@@ -4,7 +4,7 @@ import subprocess
 import sys
 
 import click
-import semver
+from packaging.version import Version, parse
 
 
 def find_root() -> pathlib.Path:
@@ -55,11 +55,21 @@ def main() -> None:
         click.echo(out.stderr, nl=False, err=True)
         sys.exit(out.returncode)
     today = datetime.date.today()
-    current = semver.Version(today.year % 100, today.month, 0)
+    current = Version(f"{today.year % 100}.{today.month}.0")
     versions = []
     for line in out.stdout.splitlines():
         try:
-            versions.append(semver.parse(line.strip()))
+            version = parse(line.strip())
+            if not isinstance(version, Version):
+                # LegacyVersion
+                continue
+            if version.epoch:
+                # Versions with epoch are not semver compliant
+                continue
+            if version.base_version != str(version):
+                # Pre, post, and dev releases are not semver compliant
+                continue
+            versions.append(version)
         except ValueError:
             pass
     versions = [
@@ -71,7 +81,8 @@ def main() -> None:
     if not versions:
         version = current
     else:
-        version = versions[-1].next_patch
+        prev = versions[-1]
+        version = Version(f"{prev.major}.{prev.minor}{prev.micro + 1}")
 
     click.echo(f"Tag version v{version}:")
     click.secho(f"git tag -a v{version} -m 'Release {version}'", bold=True)
